@@ -10,6 +10,7 @@
 #include "linearalgebra.h"
 #include "loglik_POCov.h"
 #include "nelmin.h"
+#include "random.h"
 // [[Rcpp::depends(RcppArmadillo,RcppProgress)]]
 
 // [[Rcpp::export]]
@@ -206,8 +207,8 @@ Rcpp::List fmodel1p(const arma::mat& Outcome,
 				mat qq1 = Omega0inv + (gamstar * gamstar.t());
 				gamstar = gamR.rows(nw*jj+nn, nw*(jj+1)-1);
 				mat qq2 = Omega0inv + (gamstar * gamstar.t());
-				mat ominv1 = arma::wishrnd(arma::inv(qq1), shape_omega1);
-				mat ominv2 = arma::wishrnd(arma::inv(qq2), shape_omega2);
+				mat ominv1 = RNG::rwish(arma::inv(qq1), shape_omega1);
+				mat ominv2 = RNG::rwish(arma::inv(qq2), shape_omega2);
 				mat om1 = arma::inv(ominv1);
 				mat om2 = arma::inv(ominv2);
 				Omegainv(arma::span(nw*jj, nw*jj+nn-1), arma::span(nw*jj, nw*jj+nn-1)) = ominv1;
@@ -372,8 +373,8 @@ Rcpp::List fmodel1p(const arma::mat& Outcome,
 					mat qq1 = Omega0inv + (gamstar * gamstar.t());
 					gamstar = gamR.rows(nw*jj+nn, nw*(jj+1)-1);
 					mat qq2 = Omega0inv + (gamstar * gamstar.t());
-					mat ominv1 = arma::wishrnd(arma::inv(qq1), shape_omega1);
-					mat ominv2 = arma::wishrnd(arma::inv(qq2), shape_omega2);
+					mat ominv1 = RNG::rwish(arma::inv(qq1), shape_omega1);
+					mat ominv2 = RNG::rwish(arma::inv(qq2), shape_omega2);
 					mat om1 = arma::inv(ominv1);
 					mat om2 = arma::inv(ominv2);
 					Omegainv(arma::span(nw*jj, nw*jj+nn-1), arma::span(nw*jj, nw*jj+nn-1)) = ominv1;
