@@ -14,6 +14,10 @@
 #include "random.h"
 // [[Rcpp::depends(RcppArmadillo,RcppProgress)]]
 
+/*
+* - DY February 7, 2023: replaced try-catch blocks for positive-definiteness checking with Armadillo .is_sympd()
+*/
+
 // [[Rcpp::export]]
 Rcpp::List fmodel3(const arma::mat& Outcome,
 				   const arma::mat& SD,
@@ -316,15 +320,17 @@ Rcpp::List fmodel3(const arma::mat& Outcome,
 			mat pRRho = vecrinv(z, J);
 			pRRho.diag().fill(1.0);
 			mat Rhop = pRho_to_Rho(pRRho);
-			mat Rhopinv;
-			bool rho_proceed = true;
-			try {
-				Rhopinv = arma::inv(Rhop);
-			} catch (std::runtime_error & e) {
-				rho_proceed = false;
-			}
+			// mat Rhopinv;
+			// bool rho_proceed = true;
+			// try {
+			// 	Rhopinv = arma::inv(Rhop);
+			// } catch (std::runtime_error & e) {
+			// 	rho_proceed = false;
+			// }
 
-			if (rho_proceed) {
+			// if (rho_proceed) {
+			if (Rhop.is_sympd()) {
+				arma::mat Rhopinv = arma::inv(Rhop);
 				// log-likelihood difference
 				double ll_diff = loglik_vRho_m3(vRhop, Rhopinv, qq, JJm12, sumNpt) - loglik_vRho_m3(vRho, Rhoinv, qq, JJm12, sumNpt);
 
@@ -336,38 +342,43 @@ Rcpp::List fmodel3(const arma::mat& Outcome,
 				} else {
 					// delayed rejection
 					U.randn();
-					vec zzz = vRho + std::sqrt(0.5) * (SS * U);
+					arma::vec zzz = vRho + std::sqrt(0.5) * (SS * U);
 
-					mat pRRhozzz = vecrinv(arma::tanh(zzz), J);
+					arma::mat pRRhozzz = vecrinv(arma::tanh(zzz), J);
 					pRRhozzz.diag().fill(1.0);
-					mat Rhopzzz = pRho_to_Rho(pRRhozzz);
-					mat Rhopinvzzz;
-					try {
-						Rhopinvzzz = arma::inv(Rhopzzz);
-					} catch (std::runtime_error & e) {
-						continue;
-					}
-
-					vec ystar = zzz - (vRhop - vRho);
-					mat pRRhoystar = vecrinv(arma::tanh(ystar), J);
-					pRRhoystar.diag().fill(1.0);
-					mat Rhopystar = pRho_to_Rho(pRRhoystar);
-					mat Rhopinvystar;
-					try {
-						Rhopinvystar = arma::inv(Rhopystar);
-					} catch (std::runtime_error & e) {
-						continue;
-					}
-					double log1pxy = std::log1p(-std::min(1.0, std::exp(ll_diff)));
-					double ll_diff_zystar = loglik_vRho_m3(zzz, Rhopinvzzz, qq, JJm12, sumNpt) - loglik_vRho_m3(ystar, Rhopinvystar, qq, JJm12, sumNpt);
-					double log1pzystar = std::log1p(-std::min(1.0, std::exp(ll_diff_zystar)));
-					double ll_diff_zx = loglik_vRho_m3(zzz, Rhopinvzzz, qq, JJm12, sumNpt) - loglik_vRho_m3(vRho, Rhoinv, qq, JJm12, sumNpt);
-					ll_diff = ll_diff_zx + log1pzystar - log1pxy;
-					if (std::log(::unif_rand()) < ll_diff) {
-						vRho = zzz;
-						Rho = Rhopzzz;
-						Rhoinv = Rhopinvzzz;
-						++vRho_rates;
+					arma::mat Rhopzzz = pRho_to_Rho(pRRhozzz);
+					// arma::mat Rhopinvzzz;
+					// try {
+					// 	Rhopinvzzz = arma::inv(Rhopzzz);
+					// } catch (std::runtime_error & e) {
+					// 	continue;
+					// }
+					if (Rhopzzz.is_sympd()) {
+						arma::mat Rhopinvzzz = arma::inv(Rhopzzz);
+						vec ystar = zzz - (vRhop - vRho);
+						mat pRRhoystar = vecrinv(arma::tanh(ystar), J);
+						pRRhoystar.diag().fill(1.0);
+						mat Rhopystar = pRho_to_Rho(pRRhoystar);
+						// mat Rhopinvystar;
+						// try {
+						// 	Rhopinvystar = arma::inv(Rhopystar);
+						// } catch (std::runtime_error & e) {
+						// 	continue;
+						// }
+						if (Rhopystar.is_sympd()) {
+							arma::mat Rhopinvystar = arma::inv(Rhopystar);
+							double log1pxy = std::log1p(-std::min(1.0, std::exp(ll_diff)));
+							double ll_diff_zystar = loglik_vRho_m3(zzz, Rhopinvzzz, qq, JJm12, sumNpt) - loglik_vRho_m3(ystar, Rhopinvystar, qq, JJm12, sumNpt);
+							double log1pzystar = std::log1p(-std::min(1.0, std::exp(ll_diff_zystar)));
+							double ll_diff_zx = loglik_vRho_m3(zzz, Rhopinvzzz, qq, JJm12, sumNpt) - loglik_vRho_m3(vRho, Rhoinv, qq, JJm12, sumNpt);
+							ll_diff = ll_diff_zx + log1pzystar - log1pxy;
+							if (std::log(::unif_rand()) < ll_diff) {
+								vRho = zzz;
+								Rho = Rhopzzz;
+								Rhoinv = Rhopinvzzz;
+								++vRho_rates;
+							}
+						}
 					}
 				}
 				double alpha_n = std::min(1.0, std::exp(ll_diff));
@@ -669,14 +680,16 @@ Rcpp::List fmodel3(const arma::mat& Outcome,
 				mat pRRho = vecrinv(z, J);
 				pRRho.diag().fill(1.0);
 				mat Rhop = pRho_to_Rho(pRRho);
-				mat Rhopinv;
-				bool rho_proceed = true;
-				try {
-					Rhopinv = arma::inv(Rhop);
-				} catch (std::runtime_error & e) {
-					rho_proceed = false;
-				}
-				if (rho_proceed) {
+				// mat Rhopinv;
+				// bool rho_proceed = true;
+				// try {
+				// 	Rhopinv = arma::inv(Rhop);
+				// } catch (std::runtime_error & e) {
+				// 	rho_proceed = false;
+				// }
+				// if (rho_proceed) {
+				if (Rhop.is_sympd()) {
+					arma::mat Rhopinv = arma::inv(Rhop);
 					// log-likelihood difference
 					double ll_diff = loglik_vRho_m3(vRhop, Rhopinv, qq, JJm12, sumNpt) - loglik_vRho_m3(vRho, Rhoinv, qq, JJm12, sumNpt);
 
@@ -693,33 +706,38 @@ Rcpp::List fmodel3(const arma::mat& Outcome,
 						mat pRRhozzz = vecrinv(arma::tanh(zzz), J);
 						pRRhozzz.diag().fill(1.0);
 						mat Rhopzzz = pRho_to_Rho(pRRhozzz);
-						mat Rhopinvzzz;
-						try {
-							Rhopinvzzz = arma::inv(Rhopzzz);
-						} catch (std::runtime_error & e) {
-							continue;
-						}
-
-						vec ystar = zzz - (vRhop - vRho);
-						mat pRRhoystar = vecrinv(arma::tanh(ystar), J);
-						pRRhoystar.diag().fill(1.0);
-						mat Rhopystar = pRho_to_Rho(pRRhoystar);
-						mat Rhopinvystar;
-						try {
-							Rhopinvystar = arma::inv(Rhopystar);
-						} catch (std::runtime_error & e) {
-							continue;
-						}
-						double log1pxy = std::log1p(-std::min(1.0, std::exp(ll_diff)));
-						double ll_diff_zystar = loglik_vRho_m3(zzz, Rhopinvzzz, qq, JJm12, sumNpt) - loglik_vRho_m3(ystar, Rhopinvystar, qq, JJm12, sumNpt);
-						double log1pzystar = std::log1p(-std::min(1.0, std::exp(ll_diff_zystar)));
-						double ll_diff_zx = loglik_vRho_m3(zzz, Rhopinvzzz, qq, JJm12, sumNpt) - loglik_vRho_m3(vRho, Rhoinv, qq, JJm12, sumNpt);
-						ll_diff = ll_diff_zx + log1pzystar - log1pxy;
-						if (std::log(::unif_rand()) < ll_diff) {
-							vRho = zzz;
-							Rho = Rhopzzz;
-							Rhoinv = Rhopinvzzz;
-							++vRho_rates;
+						// mat Rhopinvzzz;
+						// try {
+						// 	Rhopinvzzz = arma::inv(Rhopzzz);
+						// } catch (std::runtime_error & e) {
+						// 	continue;
+						// }
+						if (Rhopzzz.is_sympd()) {
+							arma::mat Rhopinvzzz = arma::inv(Rhopzzz);
+							vec ystar = zzz - (vRhop - vRho);
+							mat pRRhoystar = vecrinv(arma::tanh(ystar), J);
+							pRRhoystar.diag().fill(1.0);
+							mat Rhopystar = pRho_to_Rho(pRRhoystar);
+							// mat Rhopinvystar;
+							// try {
+							// 	Rhopinvystar = arma::inv(Rhopystar);
+							// } catch (std::runtime_error & e) {
+							// 	continue;
+							// }
+							if (Rhopystar.is_sympd()) {
+								arma::mat Rhopinvystar = arma::inv(Rhopystar);
+								double log1pxy = std::log1p(-std::min(1.0, std::exp(ll_diff)));
+								double ll_diff_zystar = loglik_vRho_m3(zzz, Rhopinvzzz, qq, JJm12, sumNpt) - loglik_vRho_m3(ystar, Rhopinvystar, qq, JJm12, sumNpt);
+								double log1pzystar = std::log1p(-std::min(1.0, std::exp(ll_diff_zystar)));
+								double ll_diff_zx = loglik_vRho_m3(zzz, Rhopinvzzz, qq, JJm12, sumNpt) - loglik_vRho_m3(vRho, Rhoinv, qq, JJm12, sumNpt);
+								ll_diff = ll_diff_zx + log1pzystar - log1pxy;
+								if (std::log(::unif_rand()) < ll_diff) {
+									vRho = zzz;
+									Rho = Rhopzzz;
+									Rhoinv = Rhopinvzzz;
+									++vRho_rates;
+								}
+							}
 						}
 					}
 					double alpha_n = std::min(1.0, std::exp(ll_diff));
